# Project Description

UOLogging is a solution for configuring Python's built-in logging module.

## Table of Contents

This documentation is split into the following sections:

* [User Guide](user-guide.md)
* [Developer Guide](development.md)
* [Release Notes](release-notes.md)
* [Deployment Guide](jenkins-cicd.md)

## MkDocs 

This `docs/` directory is best viewed as a simple web site via MkDocs.
For full documentation, see [mkdocs.org](https://www.mkdocs.org).

* `mkdocs serve` - Start the live-reloading docs server locally.
* `mkdocs help` - Show help info for mkdocs.
